@@ -214,9 +214,11 @@ class Protocol(object):
 
         self.__api_token = data["access_token"]
         if "refresh_token" in data:
+            _logger.debug("Token refreshed. Updating token.")
             self.__refresh_token = data["refresh_token"]
 
         if "expires_in" in data:
+            _logger.debug("Token refreshed. Updating expiry time.")
             self.__api_expires = datetime.now() + timedelta(
                 seconds=int(data["expires_in"]) / 1000
             )
